tweet

---

`tweet` can tweet now your status from CLI easily.  
`tweet` cat tweet `only`, so you will not be distracted.

## How to Install

```
pip install tweet
```

## How to Use

```
tweet {your-message}
```

## How to set up

You have to set up `~/.twitter-env` file to your home directory yourself.

`~/.twitter-env`

```env
CONSUMER_TOKEN=.......
CONSUMER_SECRET=.......
ACCESS_TOKEN=.......
ACCESS_SECRET=.....
```
